==> obb-0.5.tar.gz: obb-0.5/src/OBBSound/OBBSongDocument.py <==
#   Copyright (C) 2002-2003 Yannick Gingras <ygingras@ygingras.net>
#   Copyright (C) 2002-2003 Vincent Barbin <vbarbin@openbeatbox.org>

#   This file is part of Open Beat Box.

#   Open Beat Box is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.

#   Open Beat Box is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.

#   You should have received a copy of the GNU General Public License
#   along with Open Beat Box; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from OBBOrchestra import *
from OBBScore import *
from qt import *
from os import *

class OBBSongDocument:
    def __init__(self, tempo = 240, fileName = "Untitled1.obb"):
        if fileName == "Untitled1.obb":
            self.samplePath = None
            self.songOrchestra = OBBOrchestra()
            self.songScore = OBBScore()
            self.songTempo = tempo
        self.changed = 0


    def setTempo(self, newValue):
        self.songTempo = newValue
        self.changed = 1

    def getTempo(self):
        return self.songTempo

    def setSample(self, path):
        self.samplePath = path

    def removeSample(self):
        if self.samplePath != None:
            remove(self.samplePath)
            self.samplePath = None
            
    def getInstrument(self, InstrId):
        if InstrId in self.songOrchestra.get():
            return self.songOrchestra.get()[InstrId]

==> obb-0.7.tar.gz: obb-0.7/src/OBBSound/OBBSongDocument.py <==
#   Copyright (C) 2002-2003 Yannick Gingras <ygingras@ygingras.net>
#   Copyright (C) 2002-2003 Vincent Barbin <vbarbin@openbeatbox.org>

#   This file is part of Open Beat Box.

#   Open Beat Box is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.

#   Open Beat Box is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.

#   You should have received a copy of the GNU General Public License
#   along with Open Beat Box; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from OBBOrchestra import *
from OBBScore import *
from qt import *
from os import *
from xml.dom.minidom import *
import string

class OBBSongDocument:
    def __init__(self, tempo = 240):
        self.samplePath = None
        self.songOrchestra = OBBOrchestra()
        self.songScore = OBBScore()
        self.songTempo = tempo
        self.changed = 0
        self.fileName = ""

    def setTempo(self, newValue):
        self.songTempo = newValue
        self.changed = 1

    def getTempo(self):
        return self.songTempo

    def setSample(self, path):
        self.samplePath = path

    def removeSample(self):
        if self.samplePath != None:
            remove(self.samplePath)
            self.samplePath = None

    def getInstrument(self, InstrId):
        if InstrId in self.songOrchestra.get():
            return self.songOrchestra.get()[InstrId]

    def setFileName(self, fileName):
        self.fileName = fileName


    def getFileName(self):
        return self.fileName
    

if __name__ == "__main__":
    joe = OBBSongDocument()
